pub struct Bot {
pub id: BotId,
pub character_id: CharacterId,
pub username: String,
pub photo_url: String,
pub arena_rating: i64,
pub power: i64,
pub class_id: ClassId,
pub level: i64,
pub equipped_abilities: EquippedAbilities,
}Fields
id: BotIdcharacter_id: CharacterIdusername: Stringphoto_url: Stringarena_rating: i64power: i64class_id: ClassIdlevel: i64equipped_abilities: EquippedAbilitiesTrait Implementations
Sourceimpl CustomType for Bot
impl CustomType for Bot
Sourcefn build(builder: TypeBuilder<'_, Self>)
fn build(builder: TypeBuilder<'_, Self>)
Builds the custom type for use with the [
Engine]. Read moreSourceimpl<'de> Deserialize<'de> for Bot
impl<'de> Deserialize<'de> for Bot
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Bot
impl JsonSchema for Bot
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Tsify for Bot
impl Tsify for Bot
const DECL: &'static str = "export interface Bot {\n id: BotId;\n character_id: CharacterId;\n username: string;\n photo_url: string;\n arena_rating: number;\n power: number;\n class_id: ClassId;\n level: number;\n equipped_abilities: EquippedAbilities;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for Bot
impl StructuralPartialEq for Bot